#============================================================================
#                      MERGECOM-3 Application Configurations
#============================================================================
#
#                   ==== MergeCOM-3 Application Profiles ===
#
#      The location of this file is provided in the MERGECOM_3_APPLICATIONS
#          parameter of the [MergeCOM3] section of the MERGE.INI file
# .
#============================================================================
#
#  Contains the following sections:
#    [<remote_application_title>]- Section describing a remote DICOM application
#                                  <remote_application_title> names must be
#                                  1 to 16 bytes in length with no embedded 
#                                  spaces.  This section is only used by 
#                                  SCU applications to configure systems they 
#                                  will connect with.
#                                 
#    [<service_list_name>]      - List[s] of DICOM services (referenced by
#                                 entries in the [<remote_application_title>] 
#                                 sections.  These section names are also used
#                                 by the MC_Wait_For_Association function to
#                                 specify an SCP's services supported.
#                                 <service_list_name> names must be
#                                 1 to 33 bytes in length with no embedded 
#                                 spaces.  
#                                 
#    [<syntax_list_name>]       - List[s] of DICOM transfer syntaxes (referenced 
#                                 by optional entries in the [<service_list_name>]
#                                 sections. 
#                                 <syntax_list_name> names must be
#                                 1 to 33 bytes in length with no embedded 
#                                 spaces.
#


# Each [<remote_application_title>] section is of this format:
#       PORT_NUMBER     = <port>          is the TCP/IP port on which the 
#                                         remote DICOM system listens for 
#                                         connections.  The commonly used port 
#                                         number is 104. This default value may
#                                         be overriden by the 
#                                         MC_Open_Association() function call.
#       HOST_NAME       = <TCP/IP name>   is the name of the remote host as it
#                                         is known to your TCP/IP system.  This
#                                         default value may be overriden by 
#                                         the MC_Open_Association() function 
#                                         call.
#                                         <TCP/IP name> must be 1 to 19 bytes 
#                                         in length with no embedded spaces.
#       SERVICE_LIST    = <list name>     is the name of another section in 
#                                         this file which provides a list of 
#                                         services local applications will 
#                                         negotiate for when attempting to
#                                         establish an association.  This is a
#                                         default list; another list may be 
#                                         specified in the 
#                                         MC_Open_Association() call.
#                                         <list name> names must be 1 to 33 
#                                         bytes in length with no embedded 
#                                         spaces.

[MERGE_STORE_SCP]
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Storage_SCU_Service_List

[MERGE_STORE_SCU]
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged.  This example has a
#                                      different port to prevent conflicts when
#                                      testing both applications on the same
#                                      machine.  Both the storage commitment
#                                      SCU and SCP samples listen for
#                                      associations.
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Storage_Commit_SCP_Service_List

[MERGE_MEDIA_FSU]
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Storage_SCP_Service_List 
    
[MERGE_QR_SCP]
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Query_SCU_Service_List #!!!!
    
[MERGE_QR_SCU]
    PORT_NUMBER     = 1115        # port 104 is the standard DICOM port and is
#                                      priviledged.  This example has a
#                                      different port to prevent conflicts when
#                                      testing both applications on the same
#                                      machine.  Both the Q/R SCU and SCP samples
#                                      SCP samples listen for associations.
    HOST_NAME       = localhost   # Put the remote machine name here
    SERVICE_LIST    = Storage_SCP_Service_List    

[MERGE_PRINT_SCP] 
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Print_Service_List

[MERGE_WORK_SCP]
    PORT_NUMBER     = 104        # port 104 is the standard DICOM port and is
#                                      priviledged
    HOST_NAME       = localhost  # Put the remote machine name here
    SERVICE_LIST    = Worklist_Service_List




# Each [<service_list_name>] section must contain a SERVICES_SUPPORTED
#       parameter to specify the number of services in the list.  Optionally,
#       if an application supports DICOM asynchronous communications, the 
#       maximum operations invoked and performed by the application can be
#       specified in the service list.  MAX_OPERATIONS_INVOKED specifies
#       the maximum number of requests messages an application will send
#       before processing a response message.  MAX_OPERATIONS_PERFORMED
#       specifies how many requests messages an application can recieve
#       before sending a response message.  Setting a value of '0' means
#       unlimited requests can be invoked or performed.  Leaving these 
#       options out of the service list will cause this not to be negotiated
#       and synchronous communication will be used over the association.
#
#       MAX_OPERATIONS_INVOKED = 10
#       MAX_OPERATIONS_PERFORMED = 10
#
#       Finally, a service list has five parameters for each service, of 
#       the following format:
#
#       SERVICE_n = <service name>
#       SYNTAX_LIST_n = <syntax_list_name>  (this parameter is optional)
#       ROLE_n = <role type>
#       EXT_NEG_INFO_n = <neg info>
#       REL_GENERAL_n = <service list name>
#       SERVICE_CLASS_n = <service class UID>
#
#       where:
#               SERVICE_n       the character string "SERVICE_n", with n 
#                               replaced by the number of the service being 
#                               named.
#               ROLE_n          the character string "ROLE_n", with n replaced
#                               by the number of the role being set.  The only
#                               values which may be set are SCU, SCP, or BOTH.
#                               This section is optional.  Not specifying a
#                               role will default to a requestor = SCU, and
#                               acceptor = SCP.
#               SYNTAX_LIST_n   the character string "SYNTAX_LIST_n", with n 
#                               replaced by the number of the service for 
#                               which a list of transfer syntaxes to support
#                               is specified.
#               EXT_NEG_INFO_n  the character string "EXT_NEG_INFO_n", with n 
#                               replaced by the number of the service for 
#                               which extended negotiation is specified.  Note
#                               that this extended negotation information is 
#                               only used by the SCU.
#               SERVICE_CLASS_n the character string "SERVICE_CLASS_N", with n 
#                               replaced by the number of the service for 
#                               which the service class UID is specified.  This
#                               item must be specified if the REL_GENERAL_n
#                               listing is specified and is specified as 
#                               defined in DICOM supplement 90.
#               REL_GENERAL_n   the character string "REL_GENERAL_n", with n 
#                               replaced by the number of the service for 
#                               which related general SOP Classes are specified
#                               as defined in DICOM supplement 90.  This 
#                               setting points to another service list that
#                               contains generalized SOP Classes for this
#                               specific SOP Class.  These generalized SOP 
#                               classes are included in an association request
#                               PDU when specified.
#               <service name>  is the name of one of the services supported by
#                               your MergeCOM-3 system.  It must match one of 
#                               the service names described in the MergeCOM-3 
#                               Services Profile (named by the 
#                               MERGECOM_3_SERVICES parameter in the merge.ini 
#                               file).
#               <syntax_list_name>  is the name of a section that contains a 
#                               list of transfer syntaxes to support.  This
#                               parameter is optional.
#               <neg info>      is a string of hex characters signaling the 
#                               DICOM extended negotiation info to be used by
#                               an SCU when proposing an association.  The 
#                               string would be of the format 0x01 0x00 0x01, 
#                               etc.
#               <service list name> The name of a service list that contains
#                               the related general SOP Classes to this service.
#               <service class uid>  The service class UID of this service.
#                               Currently, the only defined service class UID
#                               is for the Storage Service.  It's UID is:
#                               1.2.840.10008.4.2       
#
# If a transfer syntax list is not specified, the tool kit will use the three
# non-encapsulated transfer syntaxes defined in the mergecom.pro configuration
# file (implicit VR little endian, explicit VR little endian and explicit VR big
# endian).


# Service list used by the Storage and Storage Commitment SCP application.
# This is a seperate service list because the SCU does not want to include
# the storage commitment push service class its association request.
[Storage_SCP_Service_List]
	SERVICES_SUPPORTED		= 57
	###########################################################################
	SERVICE_1				= STANDARD_ECHO
	###########################################################################
	SERVICE_2				= STANDARD_CR
	SYNTAX_LIST_2			= General_Syntax_List
	SERVICE_3				= STANDARD_CT
	SYNTAX_LIST_3			= General_Syntax_List
	SERVICE_4				= STANDARD_DX_PRESENT
	SYNTAX_LIST_4			= General_Syntax_List
	SERVICE_5				= STANDARD_DX_PROCESS
	SYNTAX_LIST_5			= General_Syntax_List
	SERVICE_6				= STANDARD_IO_PRESENT
	SYNTAX_LIST_6			= General_Syntax_List
	SERVICE_7				= STANDARD_IO_PROCESS
	SYNTAX_LIST_7			= General_Syntax_List
	SERVICE_8				= STANDARD_MG_PRESENT
	SYNTAX_LIST_8			= General_Syntax_List
	SERVICE_9				= STANDARD_MG_PROCESS
	SYNTAX_LIST_9			= General_Syntax_List
	SERVICE_10				= STANDARD_MR
	SYNTAX_LIST_10			= General_Syntax_List
	SERVICE_11				= STANDARD_NM
	SYNTAX_LIST_11			= General_Syntax_List
	SERVICE_12				= STANDARD_RT_DOSE
	SYNTAX_LIST_12			= General_Syntax_List
	SERVICE_13				= STANDARD_PET
	SYNTAX_LIST_13			= General_Syntax_List
	SERVICE_14				= STANDARD_RT_IMAGE
	SYNTAX_LIST_14			= General_Syntax_List
	SERVICE_15				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_15			= General_Syntax_List
	SERVICE_16				= STANDARD_US
	SYNTAX_LIST_16			= General_Syntax_List
	SERVICE_17				= STANDARD_US_MF
	SYNTAX_LIST_17			= General_Syntax_List
	SERVICE_18				= STANDARD_RT_PLAN
	SYNTAX_LIST_18			= General_Syntax_List
	SERVICE_19				= STANDARD_WAVEFORM_12_LEAD_ECG
	SYNTAX_LIST_19			= General_Syntax_List
	SERVICE_20				= STANDARD_VL_ENDOSCOPIC
	SYNTAX_LIST_20			= General_Syntax_List
	SERVICE_21				= STANDARD_VL_MICROSCOPIC
	SYNTAX_LIST_21			= General_Syntax_List
	SERVICE_22				= STANDARD_VL_PHOTOGRAPHIC
	SYNTAX_LIST_22			= General_Syntax_List
	SERVICE_23				= STANDARD_VL_SLIDE_MICROSCOPIC
	SYNTAX_LIST_23			= General_Syntax_List
	SERVICE_24				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_24			= General_Syntax_List
	SERVICE_25				= STANDARD_XRAY_RF
	SYNTAX_LIST_25			= General_Syntax_List
	SERVICE_26				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_26			= General_Syntax_List
	SERVICE_27				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_27			= General_Syntax_List
	SERVICE_28				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_28			= General_Syntax_List	
	###########################################################################
	SERVICE_29				= RAW_DATA
	###########################################################################
	SERVICE_30				= MR_SPECTROSCOPY
	###########################################################################
	SERVICE_31				= STANDARD_GRAYSCALE_SOFTCOPY_PS
	###########################################################################
	SERVICE_32				= KEY_OBJECT_SELECTION_DOC
	SERVICE_33				= STANDARD_BASIC_TEXT_SR
	SERVICE_34				= STANDARD_ENHANCED_SR
	SERVICE_35				= STANDARD_COMPREHENSIVE_SR
	SERVICE_36				= CHEST_CAD_SR
	SERVICE_37				= MAMMOGRAPHY_CAD_SR
	###########################################################################
	SERVICE_38				= STANDARD_WAVEFORM_BASIC_VOICE_AU
	###########################################################################
	SERVICE_39				= PATIENT_ROOT_QR_FIND
	SERVICE_40				= PATIENT_ROOT_QR_GET
	SERVICE_41				= PATIENT_ROOT_QR_MOVE
	SERVICE_42				= STUDY_ROOT_QR_FIND
	SERVICE_43				= STUDY_ROOT_QR_GET
	SERVICE_44				= STUDY_ROOT_QR_MOVE
	###########################################################################
	SERVICE_45				= STORAGE_COMMITMENT_PUSH
	ROLE_45					= BOTH
	###########################################################################
	SERVICE_46				= STANDARD_RT_STRUCTURE_SET
	###########################################################################
	SERVICE_47				= STANDARD_VIDEO_PHOTOGRAPHIC
	SYNTAX_LIST_47			= MPEG2_MPML_List
	###########################################################################
	SERVICE_48				= STANDARD_VIDEO_ENDOSCOPIC
	SYNTAX_LIST_48			= MPEG2_MPML_List
	###########################################################################
	SERVICE_49				= STANDARD_WAVEFORM_GENERAL_ECG
	SERVICE_50				= STANDARD_ENCAPSULATED_PDF
	SERVICE_51				= XRAY_RADATION_DOSE_SR
	SERVICE_52				= SC_MULTIFRAME_GRAYSCALE_WORD
	SERVICE_53				= STANDARD_WAVEFORM_HEMODYNAMIC
	SERVICE_54				= BREAST_TOMO_IMAGE_STORAGE
	SYNTAX_LIST_54			= General_Syntax_List		
	###########################################################################
	SERVICE_55				= STANDARD_NM_RETIRED 
	SYNTAX_LIST_55			= General_Syntax_List
	SERVICE_56				= STANDARD_US_MF_RETIRED
	SYNTAX_LIST_56			= General_Syntax_List
	SERVICE_57				= STANDARD_US_RETIRED
	SYNTAX_LIST_57			= General_Syntax_List

# Storage SCU service list.  This includes all of the standard image types.
[Storage_SCU_Service_List]
	SERVICES_SUPPORTED		= 128
	###########################################################################
	SERVICE_1				= STANDARD_ECHO
	###########################################################################
	SERVICE_2				= STANDARD_CR
	SERVICE_3				= STANDARD_CT
	SERVICE_4				= STANDARD_DX_PRESENT
	SERVICE_5				= STANDARD_DX_PROCESS
	SERVICE_6				= STANDARD_IO_PRESENT
	SERVICE_7				= STANDARD_IO_PROCESS
	SERVICE_8				= STANDARD_MG_PRESENT
	SERVICE_9				= STANDARD_MG_PROCESS
	SERVICE_10				= STANDARD_MR
	SERVICE_11				= STANDARD_NM
	#SERVICE_12				= STANDARD_NM_RETIRED 
	SERVICE_12				= XRAY_RADATION_DOSE_SR
	SERVICE_13				= STANDARD_PET
	SERVICE_14				= STANDARD_RT_IMAGE
	SERVICE_15				= STANDARD_SEC_CAPTURE
	SERVICE_16				= STANDARD_US
	SERVICE_17				= STANDARD_US_MF
	#SERVICE_18				= STANDARD_US_MF_RETIRED
	SERVICE_18				= SC_MULTIFRAME_GRAYSCALE_WORD
	#SERVICE_19				= STANDARD_US_RETIRED
	SERVICE_19				= STANDARD_WAVEFORM_HEMODYNAMIC
	SERVICE_20				= STANDARD_VL_ENDOSCOPIC
	SERVICE_21				= STANDARD_VL_MICROSCOPIC
	SERVICE_22				= STANDARD_VL_PHOTOGRAPHIC
	SERVICE_23				= STANDARD_VL_SLIDE_MICROSCOPIC
	SERVICE_24				= STANDARD_XRAY_ANGIO
	SERVICE_25				= STANDARD_XRAY_RF
	SERVICE_26				= ENHANCED_CT_IMAGE
	SERVICE_27				= ENHANCED_MR_IMAGE
	SERVICE_28				= SC_MULTIFRAME_TRUE_COLOR
	###########################################################################
	SERVICE_29				= BREAST_TOMO_IMAGE_STORAGE
	SYNTAX_LIST_29			= JPEG2000_Lossless_Syntax_List	
	#Redmine 31954 - Tomo. RLE support.
	SERVICE_30				= BREAST_TOMO_IMAGE_STORAGE
	SYNTAX_LIST_30			= RLE_Syntax_List	
	###########################################################################
	#SERVICE_30				= MR_SPECTROSCOPY
	###########################################################################
	SERVICE_31				= STANDARD_GRAYSCALE_SOFTCOPY_PS
	###########################################################################
	SERVICE_32				= KEY_OBJECT_SELECTION_DOC
	SERVICE_33				= STANDARD_BASIC_TEXT_SR
	SERVICE_34				= STANDARD_ENHANCED_SR
	SERVICE_35				= STANDARD_COMPREHENSIVE_SR
	SERVICE_36				= CHEST_CAD_SR
	SERVICE_37				= MAMMOGRAPHY_CAD_SR
	###########################################################################
	SERVICE_38				= STANDARD_WAVEFORM_BASIC_VOICE_AU
	###########################################################################
	SERVICE_39				= PATIENT_ROOT_QR_FIND
	SERVICE_40				= PATIENT_ROOT_QR_GET
	SERVICE_41				= PATIENT_ROOT_QR_MOVE
	SERVICE_42				= STUDY_ROOT_QR_FIND
	SERVICE_43				= STUDY_ROOT_QR_GET
	SERVICE_44				= STUDY_ROOT_QR_MOVE
	###########################################################################
	SERVICE_45				= STANDARD_DX_PRESENT
	SYNTAX_LIST_45			= JPEG_Extended_Syntax_List	
	SERVICE_46				= STANDARD_DX_PRESENT
	SYNTAX_LIST_46			= JPEG_Lossless_Syntax_List	
	###########################################################################
	SERVICE_47				= STANDARD_DX_PROCESS
	SYNTAX_LIST_47			= JPEG_Extended_Syntax_List		
	SERVICE_48				= STANDARD_DX_PROCESS
	SYNTAX_LIST_48			= JPEG_Lossless_Syntax_List	
	###########################################################################
	SERVICE_49				= STANDARD_CR
	SYNTAX_LIST_49			= JPEG_Baseline_Syntax_List	
	SERVICE_50				= STANDARD_CR
	SYNTAX_LIST_50			= JPEG_Extended_Syntax_List	
	SERVICE_51				= STANDARD_CR
	SYNTAX_LIST_51			= JPEG_Lossless_Syntax_List	
	SERVICE_52				= STANDARD_CR
	SYNTAX_LIST_52			= JPEG_LosslessNH_Syntax_List	
	SERVICE_53				= STANDARD_CR
	SYNTAX_LIST_53			= JPEG2000_Lossless_Syntax_List	
	SERVICE_54				= STANDARD_CR
	SYNTAX_LIST_54			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_55				= STANDARD_CT
	SYNTAX_LIST_55			= JPEG_Baseline_Syntax_List	
	SERVICE_56				= STANDARD_CT
	SYNTAX_LIST_56			= JPEG_Extended_Syntax_List	
	SERVICE_57				= STANDARD_CT
	SYNTAX_LIST_57			= JPEG_Lossless_Syntax_List	
	SERVICE_58				= STANDARD_CT
	SYNTAX_LIST_58			= JPEG_LosslessNH_Syntax_List	
	SERVICE_59				= STANDARD_CT
	SYNTAX_LIST_59			= JPEG2000_Lossless_Syntax_List	
	SERVICE_60				= STANDARD_CT
	SYNTAX_LIST_60			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_61				= STANDARD_MR
	SYNTAX_LIST_61			= JPEG_Baseline_Syntax_List	
	SERVICE_62				= STANDARD_MR
	SYNTAX_LIST_62			= JPEG_Extended_Syntax_List	
	SERVICE_63				= STANDARD_MR
	SYNTAX_LIST_63			= JPEG_Lossless_Syntax_List	
	SERVICE_64				= STANDARD_MR
	SYNTAX_LIST_64			= JPEG_LosslessNH_Syntax_List	
	SERVICE_65				= STANDARD_MR
	SYNTAX_LIST_65			= JPEG2000_Lossless_Syntax_List	
	SERVICE_66				= STANDARD_MR
	SYNTAX_LIST_66			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_67				= STANDARD_NM
	SYNTAX_LIST_67			= JPEG_Lossless_Syntax_List	
	###########################################################################
	SERVICE_68				= STANDARD_PET
	SYNTAX_LIST_68			= JPEG_Lossless_Syntax_List
	SERVICE_69				= STANDARD_PET
	SYNTAX_LIST_69			= JPEG2000_Lossless_Syntax_List		
	###########################################################################
	SERVICE_70				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_70			= JPEG_Baseline_Syntax_List	
	SERVICE_71				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_71			= JPEG_Extended_Syntax_List	
	SERVICE_72				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_72			= JPEG_Lossless_Syntax_List	
	SERVICE_73				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_73			= JPEG_LosslessNH_Syntax_List	
	SERVICE_74				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_74			= JPEG2000_Lossless_Syntax_List	
	SERVICE_75				= STANDARD_SEC_CAPTURE
	SYNTAX_LIST_75			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_76				= STANDARD_US
	SYNTAX_LIST_76			= JPEG_Baseline_Syntax_List	
	SERVICE_77				= STANDARD_US
	SYNTAX_LIST_77			= JPEG_Lossless_Syntax_List	
	SERVICE_78				= STANDARD_US
	SYNTAX_LIST_78			= JPEG2000_Lossless_Syntax_List	
	SERVICE_79				= STANDARD_US
	SYNTAX_LIST_79			= JPEG2000_Lossy_Syntax_List	
	SERVICE_80				= STANDARD_US
	SYNTAX_LIST_80			= RLE_Syntax_List	
	###########################################################################
	#SERVICE_81				= STANDARD_US_RETIRED
	#SYNTAX_LIST_81			= JPEG_Baseline_Syntax_List	
	#SERVICE_81				= STANDARD_RT_DOSE
	# #33350, #31936
	SERVICE_81				= STANDARD_MG_PRESENT
	SYNTAX_LIST_81			= JPEG2000_Lossy_Syntax_List
	#SERVICE_82				= STANDARD_US_RETIRED
	#SYNTAX_LIST_82			= JPEG_Lossless_Syntax_List	
	SERVICE_82				= STANDARD_ENCAPSULATED_PDF
	#SERVICE_83				= STANDARD_US_RETIRED
	#SYNTAX_LIST_83			= JPEG2000_Lossless_Syntax_List	
	SERVICE_83				= STANDARD_RT_PLAN
	#SERVICE_84				= STANDARD_US_RETIRED
	#SYNTAX_LIST_84			= JPEG2000_Lossy_Syntax_List	
	SERVICE_84				= STANDARD_WAVEFORM_12_LEAD_ECG
	#SERVICE_85				= STANDARD_US_RETIRED
	#SYNTAX_LIST_85			= RLE_Syntax_List	
	SERVICE_85				= STANDARD_WAVEFORM_GENERAL_ECG
	###########################################################################
	SERVICE_86				= STANDARD_US_MF
	SYNTAX_LIST_86			= JPEG_Baseline_Syntax_List	
	SERVICE_87				= STANDARD_US_MF
	SYNTAX_LIST_87			= JPEG2000_Lossless_Syntax_List	
	SERVICE_88				= STANDARD_US_MF
	SYNTAX_LIST_88			= JPEG2000_Lossy_Syntax_List	
	SERVICE_89				= STANDARD_US_MF
	SYNTAX_LIST_89			= RLE_Syntax_List	
	###########################################################################
	#SERVICE_90				= STANDARD_US_MF_RETIRED
	#SYNTAX_LIST_90			= JPEG_Baseline_Syntax_List	
	SERVICE_90				= STANDARD_RT_STRUCTURE_SET
	#SERVICE_91				= STANDARD_US_MF_RETIRED
	#SYNTAX_LIST_91			= JPEG2000_Lossless_Syntax_List	
	SERVICE_91				= BREAST_TOMO_IMAGE_STORAGE
	#SYNTAX_LIST_91			= JPEG2000_Lossless_Syntax_List	
	#SERVICE_92				= STANDARD_US_MF_RETIRED
	#SYNTAX_LIST_92			= JPEG2000_Lossy_Syntax_List	
	SERVICE_92				= STANDARD_VIDEO_ENDOSCOPIC
	SYNTAX_LIST_92			= MPEG2_MPML_List
	#SERVICE_93				= STANDARD_US_MF_RETIRED
	#SYNTAX_LIST_93			= RLE_Syntax_List	
	SERVICE_93				= STANDARD_VIDEO_PHOTOGRAPHIC
	SYNTAX_LIST_93			= MPEG2_MPML_List
	###########################################################################
	SERVICE_94				= STANDARD_VL_ENDOSCOPIC
	SYNTAX_LIST_94			= JPEG_Baseline_Syntax_List	
	SERVICE_95				= STANDARD_VL_MICROSCOPIC
	SYNTAX_LIST_95			= JPEG_Baseline_Syntax_List	
	SERVICE_96				= STANDARD_VL_PHOTOGRAPHIC
	SYNTAX_LIST_96			= JPEG_Baseline_Syntax_List	
	SERVICE_97				= STANDARD_VL_SLIDE_MICROSCOPIC
	SYNTAX_LIST_97			= JPEG_Baseline_Syntax_List
	###########################################################################	
	SERVICE_98				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_98			= JPEG_Baseline_Syntax_List	
	SERVICE_99				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_99			= JPEG_Extended_Syntax_List	
	SERVICE_100				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_100			= JPEG_Lossless_Syntax_List	
	SERVICE_101				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_101			= JPEG_LosslessNH_Syntax_List	
	SERVICE_102				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_102			= JPEG2000_Lossless_Syntax_List	
	SERVICE_103				= STANDARD_XRAY_ANGIO
	SYNTAX_LIST_103			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_104				= STANDARD_XRAY_RF
	SYNTAX_LIST_104			= JPEG_Baseline_Syntax_List	
	SERVICE_105				= STANDARD_XRAY_RF
	SYNTAX_LIST_105			= JPEG_Extended_Syntax_List	
	SERVICE_106				= STANDARD_XRAY_RF
	SYNTAX_LIST_106			= JPEG_Lossless_Syntax_List	
	SERVICE_107				= STANDARD_XRAY_RF
	SYNTAX_LIST_107			= JPEG_LosslessNH_Syntax_List	
	SERVICE_108				= STANDARD_XRAY_RF
	SYNTAX_LIST_108			= JPEG2000_Lossless_Syntax_List	
	SERVICE_109				= STANDARD_XRAY_RF
	SYNTAX_LIST_109			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_110				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_110			= JPEG_Baseline_Syntax_List	
	SERVICE_111				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_111			= JPEG_Extended_Syntax_List	
	SERVICE_112				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_112			= JPEG_Lossless_Syntax_List	
	SERVICE_113				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_113			= JPEG_LosslessNH_Syntax_List	
	SERVICE_114				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_114			= JPEG2000_Lossless_Syntax_List	
	SERVICE_115				= ENHANCED_CT_IMAGE
	SYNTAX_LIST_115			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_116				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_116			= JPEG_Baseline_Syntax_List	
	SERVICE_117				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_117			= JPEG_Extended_Syntax_List	
	SERVICE_118				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_118			= JPEG_Lossless_Syntax_List	
	SERVICE_119				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_119			= JPEG_LosslessNH_Syntax_List	
	SERVICE_120				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_120			= JPEG2000_Lossless_Syntax_List	
	SERVICE_121				= ENHANCED_MR_IMAGE
	SYNTAX_LIST_121			= JPEG2000_Lossy_Syntax_List	
	###########################################################################
	SERVICE_122				= STANDARD_MG_PRESENT
	SYNTAX_LIST_122			= JPEG2000_Lossless_Syntax_List
	###########################################################################
	SERVICE_123				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_123			= JPEG_Baseline_Syntax_List	
	SERVICE_124				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_124			= JPEG_Extended_Syntax_List	
	SERVICE_125				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_125			= JPEG_Lossless_Syntax_List	
	SERVICE_126				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_126			= JPEG_LosslessNH_Syntax_List	
	SERVICE_127				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_127			= JPEG2000_Lossless_Syntax_List	
	SERVICE_128				= SC_MULTIFRAME_TRUE_COLOR
	SYNTAX_LIST_128			= JPEG2000_Lossy_Syntax_List

###############################################################################################

[General_Syntax_List]
	SYNTAXES_SUPPORTED		= 10
	SYNTAX_1				= EXPLICIT_LITTLE_ENDIAN
	SYNTAX_2				= IMPLICIT_LITTLE_ENDIAN
	SYNTAX_3				= EXPLICIT_BIG_ENDIAN
	SYNTAX_4				= JPEG_LOSSLESS_HIER_14
	SYNTAX_5				= JPEG_LOSSLESS_NON_HIER_14
	SYNTAX_6				= JPEG_EXTENDED_2_4
	SYNTAX_7				= JPEG_BASELINE
	SYNTAX_8				= RLE
	SYNTAX_9				= JPEG_2000_LOSSLESS_ONLY
	SYNTAX_10				= JPEG_2000

[Native_Syntax_List]
	SYNTAXES_SUPPORTED		= 3
	SYNTAX_1				= EXPLICIT_LITTLE_ENDIAN
	SYNTAX_2				= IMPLICIT_LITTLE_ENDIAN
	SYNTAX_3				= EXPLICIT_BIG_ENDIAN

[Default_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= IMPLICIT_LITTLE_ENDIAN

[Explicit_Little_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= EXPLICIT_LITTLE_ENDIAN

[Implicit_Little_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= IMPLICIT_LITTLE_ENDIAN

[Explicit_Big_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= EXPLICIT_BIG_ENDIAN

[JPEG_Lossless_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_LOSSLESS_HIER_14

[JPEG_LosslessNH_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_LOSSLESS_NON_HIER_14

[JPEG_Extended_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_EXTENDED_2_4

[JPEG_Baseline_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_BASELINE

[RLE_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= RLE

[JPEG2000_Lossless_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_2000_LOSSLESS_ONLY

[JPEG2000_Lossy_Syntax_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= JPEG_2000

[MPEG2_MPML_List]
	SYNTAXES_SUPPORTED		= 1
	SYNTAX_1				= MPEG2_MPML

###############################################################################################

[Storage_Commit_SCP_Service_List]
    SERVICES_SUPPORTED      = 1
    SERVICE_1               = STORAGE_COMMITMENT_PUSH
    ROLE_1                  = SCP

[Storage_Commit_SCU_Service_List]
    SERVICES_SUPPORTED      = 1
    SERVICE_1               = STORAGE_COMMITMENT_PUSH
    ROLE_1                  = SCU

###############################################################################################

[SR_Service_List]
	SERVICES_SUPPORTED		= 4
	SERVICE_1				= STANDARD_BASIC_TEXT_SR
	SERVICE_2				= STANDARD_ENHANCED_SR
	SERVICE_3				= STANDARD_COMPREHENSIVE_SR
	SERVICE_4				= CHEST_CAD_SR

[Basic_Text_SR_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= STANDARD_BASIC_TEXT_SR

[Enhanced_SR_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= STANDARD_ENHANCED_SR

[Comprehensive_SR_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= STANDARD_COMPREHENSIVE_SR

[Chest_CAD_SR_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= CHEST_CAD_SR

###############################################################################################

[Print_Service_List]
	SERVICES_SUPPORTED		= 3
	SERVICE_1				= BASIC_GRAYSCALE_PRINT_MANAGEMENT
	SERVICE_2				= BASIC_COLOR_PRINT_MANAGEMENT
	SERVICE_3				= PRINT_JOB

[Print_PLUT_Service_List]
	SERVICES_SUPPORTED		= 4
	SERVICE_1				= BASIC_GRAYSCALE_PRINT_MANAGEMENT
	SERVICE_2				= BASIC_COLOR_PRINT_MANAGEMENT
	SERVICE_3				= PRINT_JOB
	SERVICE_4				= PRESENTATION_LUT

[Grayscale_Print_Service_List]
	SERVICES_SUPPORTED		= 3
	SERVICE_1				= BASIC_GRAYSCALE_PRINT_MANAGEMENT
	SERVICE_2				= PRINT_JOB
	SERVICE_3				= PRESENTATION_LUT

[Color_Print_Service_List]
	SERVICES_SUPPORTED		= 3
	SERVICE_1				= BASIC_COLOR_PRINT_MANAGEMENT
	SERVICE_2				= PRINT_JOB
	SERVICE_3				= PRESENTATION_LUT

###############################################################################################

[Worklist_Service_List]
	SERVICES_SUPPORTED		= 5
    SERVICE_1				= MODALITY_WORKLIST_FIND
	SERVICE_2				= PERFORMED_PROCEDURE_STEP
	SERVICE_3				= G_P_WORKLIST
	SERVICE_4				= G_P_SCHEDULED_PROCEDURE_STEP
	SERVICE_5				= G_P_PERFORMED_PROCEDURE_STEP

[MWL_Service_List]
	SERVICES_SUPPORTED		= 1
    SERVICE_1				= MODALITY_WORKLIST_FIND

[MPPS_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= PERFORMED_PROCEDURE_STEP
	
[GPWL_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= G_P_WORKLIST
	
[GPSPS_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= G_P_SCHEDULED_PROCEDURE_STEP

[GPPPS_Service_List]
	SERVICES_SUPPORTED		= 1
	SERVICE_1				= G_P_PERFORMED_PROCEDURE_STEP
